@@ -62,7 +62,7 @@ class LayoutsMixin:
         *,
         border: bool | None = None,
         key: Key | None = None,
-        width: WidthWithoutContent = "stretch",
+        width: Width = "stretch",
         height: Height = "content",
         horizontal: bool = False,
         horizontal_alignment: HorizontalAlignment = "left",
@@ -92,11 +92,13 @@ class LayoutsMixin:
             Additionally, if ``key`` is provided, it will be used as CSS
             class name prefixed with ``st-key-``.
 
-        width : "stretch" or int
+        width : "stretch", "content", or int
             The width of the container. This can be one of the following:
 
             - ``"stretch"`` (default): The width of the container matches the
               width of the parent container.
+            - ``"content"``: The width of the container matches the width of
+              its content.
             - An integer specifying the width in pixels: The container has a
               fixed width. If the specified width is greater than the width of
               the parent container, the width of the container matches the width
@@ -199,7 +201,7 @@ class LayoutsMixin:
         >>>
         >>> st.write("This is outside the container")
 
-        .. output ::
+        .. output::
             https://doc-container1.streamlit.app/
             height: 520px
 
@@ -218,7 +220,7 @@ class LayoutsMixin:
         >>>
         >>> container.write("This is inside too")
 
-        .. output ::
+        .. output::
             https://doc-container2.streamlit.app/
             height: 300px
 
@@ -236,7 +238,7 @@ class LayoutsMixin:
         >>>     tile = col.container(height=120)
         >>>     tile.title(":balloon:")
 
-        .. output ::
+        .. output::
             https://doc-container3.streamlit.app/
             height: 350px
 
@@ -252,7 +254,7 @@ class LayoutsMixin:
         >>> with st.container(height=300):
         >>>     st.markdown(long_text)
 
-        .. output ::
+        .. output::
             https://doc-container4.streamlit.app/
             height: 400px
 
@@ -268,7 +270,7 @@ class LayoutsMixin:
         >>> for card in range(3):
         >>>     flex.button(f"Button {card + 1}")
 
-        .. output ::
+        .. output::
             https://doc-container5.streamlit.app/
             height: 250px
 
@@ -298,7 +300,7 @@ class LayoutsMixin:
             block_proto.flex_container.justify = get_justify(vertical_alignment)
             block_proto.flex_container.align = get_align(horizontal_alignment)
 
-        validate_width(width)
+        validate_width(width, allow_content=True)
         block_proto.width_config.CopyFrom(get_width_config(width))
 
         if isinstance(height, int) or border:
@@ -420,7 +422,7 @@ class LayoutsMixin:
         ...     st.header("An owl")
         ...     st.image("https://static.streamlit.io/examples/owl.jpg")
 
-        .. output ::
+        .. output::
             https://doc-columns1.streamlit.app/
             height: 620px
 
@@ -441,7 +443,7 @@ class LayoutsMixin:
         >>> col2.subheader("A narrow column with the data")
         >>> col2.write(df)
 
-        .. output ::
+        .. output::
             https://doc-columns2.streamlit.app/
             height: 550px
 
@@ -457,7 +459,7 @@ class LayoutsMixin:
         >>> middle.button("Click me", use_container_width=True)
         >>> right.checkbox("Check me")
 
-        .. output ::
+        .. output::
             https://doc-columns-bottom-widgets.streamlit.app/
             height: 200px
 
@@ -476,7 +478,7 @@ class LayoutsMixin:
         >>> middle.image("https://static.streamlit.io/examples/dog.jpg")
         >>> right.image("https://static.streamlit.io/examples/owl.jpg")
 
-        .. output ::
+        .. output::
             https://doc-columns-vertical-alignment.streamlit.app/
             height: 600px
 
@@ -493,7 +495,7 @@ class LayoutsMixin:
         >>> middle.markdown("Lorem ipsum " * 5)
         >>> right.markdown("Lorem ipsum ")
 
-        .. output ::
+        .. output::
             https://doc-columns-borders.streamlit.app/
             height: 250px
 
@@ -640,7 +642,7 @@ class LayoutsMixin:
         ...     st.header("An owl")
         ...     st.image("https://static.streamlit.io/examples/owl.jpg", width=200)
 
-        .. output ::
+        .. output::
             https://doc-tabs1.streamlit.app/
             height: 620px
 
@@ -661,7 +663,7 @@ class LayoutsMixin:
         >>> tab2.subheader("A tab with the data")
         >>> tab2.write(df)
 
-        .. output ::
+        .. output::
             https://doc-tabs2.streamlit.app/
             height: 700px
 
@@ -686,7 +688,7 @@ class LayoutsMixin:
         >>>     st.header("An owl")
         >>>     st.image("https://static.streamlit.io/examples/owl.jpg", width=200)
 
-        .. output ::
+        .. output::
             https://doc-tabs3.streamlit.app/
             height: 620px
 
@@ -791,6 +793,8 @@ class LayoutsMixin:
               <https://fonts.google.com/icons?icon.set=Material+Symbols&icon.style=Rounded>`_
               font library.
 
+            - ``"spinner"``: Displays a spinner as an icon.
+
         width : "stretch" or int
             The width of the expander container. This can be one of the following:
 
@@ -817,7 +821,7 @@ class LayoutsMixin:
         ...     ''')
         ...     st.image("https://static.streamlit.io/examples/dice.jpg")
 
-        .. output ::
+        .. output::
             https://doc-expander.streamlit.app/
             height: 750px
 
@@ -835,7 +839,7 @@ class LayoutsMixin:
         ... ''')
         >>> expander.image("https://static.streamlit.io/examples/dice.jpg")
 
-        .. output ::
+        .. output::
             https://doc-expander.streamlit.app/
             height: 750px
 
@@ -941,6 +945,8 @@ class LayoutsMixin:
               <https://fonts.google.com/icons?icon.set=Material+Symbols&icon.style=Rounded>`_
               font library.
 
+            - ``"spinner"``: Displays a spinner as an icon.
+
         disabled : bool
             An optional boolean that disables the popover button if set to
             ``True``. The default is ``False``.
@@ -993,7 +999,7 @@ class LayoutsMixin:
         >>>
         >>> st.write("Your name:", name)
 
-        .. output ::
+        .. output::
             https://doc-popover.streamlit.app/
             height: 400px
 
@@ -1010,7 +1016,7 @@ class LayoutsMixin:
         >>> if blue:
         ...     st.write(":blue[This is a blue item.]")
 
-        .. output ::
+        .. output::
             https://doc-popover2.streamlit.app/
             height: 400px
 
@@ -1142,7 +1148,7 @@ class LayoutsMixin:
         >>>
         >>> st.button("Rerun")
 
-        .. output ::
+        .. output::
             https://doc-status.streamlit.app/
             height: 300px
 
@@ -1165,7 +1171,7 @@ class LayoutsMixin:
         >>>
         >>> st.button("Rerun")
 
-        .. output ::
+        .. output::
             https://doc-status-update.streamlit.app/
             height: 300px
 
