@@ -28,6 +28,7 @@ from typing import (
     overload,
 )
 
+from streamlit import config
 from streamlit.elements.lib.form_utils import current_form_id
 from streamlit.elements.lib.layout_utils import (
     LayoutConfig,
@@ -390,7 +391,7 @@ class ButtonGroupMixin:
         >>> if selected is not None:
         >>>     st.markdown(f"You selected {sentiment_mapping[selected]} star(s).")
 
-        .. output ::
+        .. output::
             https://doc-feedback-stars.streamlit.app/
             height: 200px
 
@@ -403,7 +404,7 @@ class ButtonGroupMixin:
         >>> if selected is not None:
         >>>     st.markdown(f"You selected: {sentiment_mapping[selected]}")
 
-        .. output ::
+        .. output::
             https://doc-feedback-thumbs.streamlit.app/
             height: 200px
 
@@ -423,6 +424,30 @@ class ButtonGroupMixin:
                 f" The passed default value is {default}"
             )
 
+        # Convert small pixel widths to "content" to prevent icon wrapping.
+        # Calculate threshold based on theme.baseFontSize to be responsive to
+        # custom themes. The calculation is based on icon buttons sized in rem:
+        # - Button size: ~1.5rem (icon 1.25rem + padding 0.125rem x 2)
+        # - Gap: 0.125rem between buttons
+        # - thumbs: 2 buttons + 1 gap = 3.125rem
+        # - faces/stars: 5 buttons + 4 gaps = 8rem
+        base_font_size = config.get_option("theme.baseFontSize") or 16
+        button_size_rem = 1.5
+        gap_size_rem = 0.125
+
+        if options == "thumbs":
+            # 2 buttons + 1 gap
+            min_width_rem = 2 * button_size_rem + gap_size_rem
+        else:
+            # 5 buttons + 4 gaps (faces or stars)
+            min_width_rem = 5 * button_size_rem + 4 * gap_size_rem
+
+        # Convert rem to pixels based on base font size, add 10% buffer
+        min_width_threshold = int(min_width_rem * base_font_size * 1.1)
+
+        if isinstance(width, int) and width < min_width_threshold:
+            width = "content"
+
         _default: list[int] | None = (
             [options_indices[default]] if default is not None else None
         )
